%-------------------------------------------------------------------------------------------
%        Set parameter values of the exogenous stochastic processes and their respective priors
%        Set values and priors for measurement errors
%--------------------------------------------------------------------------------------------

rho1_lambdaf    =   0.71942; %CMR:0.71942;%BGG:0.70686;%CEE:0.69207; NoFIS=0.7382;   %AR(1) coefficient
rho2_lambdaf    =   0.0; %AR(2) coefficient
p_lambdaf       =   0;   %number of periods extending between the signal and the realisation of the shock 
std1_lambdaf    =   0.014723; %standard deviation of shock. This is used in the computation of impulse responses
std2_lambdaf    =   0.0; %standard deviation of signal. This is used in the computation of impulse responses
%set priors
prior_rho1_lambdaf = [1,0.5,0.05]; %1th column is the shape; 2nd and 3rd are parameters used to compute density (opportunely transformed if needed)
                    %shape: 1 is BETA(mean,stdd); parameters a and b needed to evaluate Beta distribution are computed automatically on the basis of the 'mean' and 'stdd' specified by the user
                    %       2 is INVGAMMA(mode,d); d gives the degrees of freedom
                    %       3 is NORMAL(mean,stdd)
                    %       4 is uniform(a,b)
                    %       5 is Gamma(mean,stdd)
                    %       6 is Weibull(a, b) where a is a scale parameter that controls the mode and b the shape 
prior_rho2_lambdaf = [1,0.5,0.2]; %1th column is the shape; 2nd and 3rd are parameters used to compute density (opportunely transformed if needed)
prior_std1_lambdaf = [2,0.0005,5]; %prior_std_lamf1 = [2,0.01,5]; %Note: prior is on std!. Smets and Wouters set d=2 in all of the invgamma priors 
prior_std2_lambdaf = [2,0.00005,2];


rho1_pitarget      =   0.965;
rho2_pitarget      =   0;
p_pitarget         =   0;
std1_pitarget      =   0.00035; %0.00035; %0.0005; %0.0003; %0.000149066345280;
std2_pitarget      =   0.000779;
%set priors on parameters
prior_rho1_pitarget = [1,0.99,0.01]; %1th column is the shape; 2nd and 3rd are parameters used to compute density
prior_rho2_pitarget = [1,0.1,0.1];
prior_std1_pitarget = [2,0.000175,5];  %prior_std1_pitarget = [2,0.000175,20]; 
prior_std2_pitarget = [2,0.0001,5];


rho1_psil      =  0.99;
rho2_psil      =  0.0;
p_psil         =  0;
std1_psil      =  0.01;
std2_psil      =  0.01;
%set priors on parameters
prior_rho1_psil = [1,0.75,0.1]; %1th column is the shape; 2nd and 3rd are parameters used to compute density 
prior_rho2_psil = [1,0.1,0.1]; 
prior_std1_psil = [2,0.00005,2]; 
prior_std2_psil = [2,0.00005,2];


rho1_psik     =   0.9;
rho2_psik     =   0;
p_psik        =   0;
std1_psik     =   0.1;
std2_psik     =   0.01;
%set priors on parameters
prior_rho1_psik = [1,0.8,0.1]; %1th column is the shape; 2nd and 3rd are parameters used to compute density 
prior_rho2_psik = [1,0.1,0.1]; 
prior_std1_psik = [2,0.2,2]; 
prior_std2_psik = [2,0.00005,2];


rho1_ksi       =   0.49163; %CMR=0.49163;  NoFIS=0.4902;
rho2_ksi       =   0;
p_ksi          =   0;
std1_ksi       =  0.0070815;
std2_ksi       =   0.01;
%set priors on parameters
prior_rho1_ksi = [1,0.5,0.2]; %1th column is the shape; 2nd and 3rd are parameters used to compute density 
prior_rho2_ksi = [1,0.1,0.1]; 
prior_std1_ksi = [2,0.001,5]; 
prior_std2_ksi = [2,0.00005,2];


rho1_xb       =  0.98563; %CMR=0.98563; NoFIS=0.9845;
rho2_xb       =  0;
p_xb          =  0;
std1_xb       =  0.079376;
std2_xb       =  0.01;
%set priors on parameters
prior_rho1_xb = [1,0.5,0.2]; %1th column is the shape; 2nd and 3rd are parameters used to compute density 
prior_rho2_xb = [1,0.1,0.1]; 
prior_std1_xb = [2,0.1,5]; %prior_stddxb1 = [2,0.1,5];
prior_std2_xb = [2,0.00005,2];


rho1_muup      =   0.98259; %CMR=0.98259; BGG=0.98325; CEE=0.98782; NoFis=0.9817
rho2_muup      =   0;
p_muup         =   0;
std1_muup      =   0.0033486;
std2_muup      =   0.00292;
%set priors on parameters
prior_rho1_muup = [1,0.5,0.2]; %1th column is the shape; 2nd and 3rd are parameters used to compute density 
prior_rho2_muup = [1,0.1,0.1]; 
prior_std1_muup = [2,0.003,5]; %prior_stddmuup1 = [2,0.003,5];
prior_std2_muup = [2,0.00005,2];


rho1_theta    =   0.936;%0.9;
rho2_theta    =   0;
p_theta       =   0;
std1_theta    =   0.6;
std2_theta    =   0.01;
%set priors on parameters
prior_rho1_theta = [1,0.85,0.1]; %1th column is the shape; 2nd and 3rd are parameters used to compute density 
prior_rho2_theta = [1,0.1,0.1]; 
prior_std1_theta = [2,0.01,2]; 
prior_std2_theta = [2,0.00005,2];


rho1_chii      =   0.97887; 
rho2_chii      =   0;
p_chii         =   0;
std1_chii      =   0.018335;
std2_chii      =   0.163;
%set priors on parameters
prior_rho1_chii = [1,0.5,0.2]; %1th column is the shape; 2nd and 3rd are parameters used to compute density 
prior_rho2_chii = [1,0.1,0.1]; 
prior_std1_chii = [2,0.001,5]; %[2,0.01,5]; 
%prior_std1_chii = [2,0.00361181157857,5]; 
prior_std2_chii = [2,0.00005,2];


rho1_taul     =   0.9;
rho2_taul     =   0;
p_taul        =   0;
std1_taul     =   0.01;
std2_taul     =   0.01;
%set priors on parameters
prior_rho1_taul = [1,0.85,0.01]; %1th column is the shape; 2nd and 3rd are parameters used to compute density 
prior_rho2_taul = [1,0.1,0.1]; 
prior_std1_taul = [2,0.01,2]; 
prior_std2_taul = [2,0.00005,2];


rho1_tauk     =   0.9;
rho2_tauk     =   0;
p_tauk        =   0; 
std1_tauk     =   0.01; %0.627;
std2_tauk     =   0.01;
%set priors on parameters
prior_rho1_tauk = [1,0.85,0.01]; %1th column is the shape; 2nd and 3rd are parameters used to compute density 
prior_rho2_tauk = [1,0.1,0.1]; 
prior_std1_tauk = [2,0.01,2]; 
prior_std2_tauk = [2,0.00005,2];


rho1_zeta     =   0.;%0.918;
rho2_zeta     =   0;
p_zeta        =   0;
std1_zeta     =   0.0129;
std2_zeta     =   0.1;
%set priors on parameters
prior_rho1_zeta = [1,0.5,0.2]; %1th column is the shape; 2nd and 3rd are parameters used to compute density 
prior_rho2_zeta = [1,0.1,0.1]; 
prior_std1_zeta = [2,0.001,5]; %prior_stddzeta1 = [2,0.002,2];
prior_std2_zeta = [2,0.00005,2];


rho1_g        =   0.94387; %CMR=0.94387; BGG=0.92766; CEE=0.94756; NoFis=0.9517
rho2_g        =   0;
p_g           =   0;
std1_g        =   0.020745;
std2_g        =   0.0;
%set priors on parameters
prior_rho1_g = [1,0.5,0.2]; %1th column is the shape; 2nd and 3rd are parameters used to compute density 
prior_rho2_g = [1,0.1,0.1]; 
prior_std1_g = [2,0.01,5]; %prior_stddg1 = [2,0.001,5];
prior_std2_g = [2,0.00005,2];


rho1_v        =   0.9;%0.9;
rho2_v        =   0;
p_v           =   0;
std1_v        =   0.1;
std2_v        =   0.1; %0.36;
%set priors on parameters
prior_rho1_v = [1,0.85,0.1]; %1th column is the shape; 2nd and 3rd are parameters used to compute density 
prior_rho2_v = [1,0.1,0.1]; 
prior_std1_v = [6,0.01,4]; 
prior_std2_v = [2,0.00005,2];


rho1_taud     =   0.923;
rho2_taud     =   0;
p_taud        =   0;
std1_taud     =   0.01;
std2_taud     =   0.01;
%set priors on parameters
prior_rho1_taud = [1,0.85,0.1]; %1th column is the shape; 2nd and 3rd are parameters used to compute density 
prior_rho2_taud = [1,0.1,0.1]; 
prior_std1_taud = [2,0.1,2]; 
prior_std2_taud = [2,0.00005,2];


rho1_muzstar      =   0.17665; %CMR=0.17665; BGG=0.1814; CEE=0.18737; NoFis=0.1864
rho2_muzstar      =   0;
p_muzstar         =   0;
std1_muzstar      =   0.0066804;%.01/(1-alpha);%set this to zero if the shock is to be realized
std2_muzstar      =   .01/(1-alpha);
%set priors on parameters
prior_rho1_muzstar = [1,0.5,0.2]; %1th column is the shape; 2nd and 3rd are parameters used to compute density 
prior_rho2_muzstar = [1,0.1,0.1]; 
prior_std1_muzstar = [2,0.001,5]; %prior_stddmuz1 = [2,0.01,5]; 
prior_std2_muzstar = [2,0.001/sqrt(8),5];


rho1_gamma    =   0.55937; %CMR=0.55937; BGG=0.56298; NoFIS=0.5537;
rho2_gamma    =   0;
p_gamma       =   8; 
std1_gamma    =   0.0040764;
std2_gamma    =   0.00027387;
%set priors on parameters
prior_rho1_gamma = [1,0.5,0.025]; %WARNING!!!! Changed from: prior_rho1_gamma = [1,0.5,0.025];
prior_rho2_gamma = [1,0.1,0.1]; 
prior_std1_gamma = [2,0.001,5]; %prior_stddgamma1 = [2,0.01,5];
%prior_std1_gamma = [2,0.04521029802953,5];  
prior_std2_gamma = [2,0.001/sqrt(8),5];


rho1_epsil      =   0.9364;%CMR:0.9364;%BGG:0.94374;%CEE:0.93613;NoFIS=0.9502;
rho2_epsil      =   0;
p_epsil         =   0;
std1_epsil      =   0.0046537;%set this to zero if you want the shock to be realized
std2_epsil      =   0.01; %0.00523;%0.00523;%0.01; %0.00253;
%set priors on parameters
prior_rho1_epsil = [1,0.5,0.2]; %1th column is the shape; 2nd and 3rd are parameters used to compute density 
prior_rho2_epsil = [1,0.1,0.1]; 
prior_std1_epsil = [2,0.001,5]; %prior_stddeps1 = [2,0.01,5]; 
prior_std2_epsil = [2,0.001/sqrt(8),5];


if Taylor == 0 || Taylor ==3
    rho1_xp    =  0; %monetary policy shock
    rho2_xp    =  0;
    p_xp       =  0;
    std1_xp    =  0.08;
    std2_xp    =  0.11;
    %set priors on parameters
    prior_rho1_xp = [1,0.85,0.1]; %1th column is the shape; 2nd and 3rd are parameters used to compute density
    prior_rho2_xp = [1,0.1,0.1];
    prior_std1_xp = [2,0.0001,10];
    prior_std2_xp = [2,0.00005,2];
end
if Taylor == 1 || Taylor == 2
    rho1_xp    =   0;   %monetary policy shock
    rho2_xp    =   0;
    p_xp       =   0;
    std1_xp     =   0.52587;
    std2_xp     =   0;
    %set priors on parameters
    prior_rho1_xp = [1,0.1,0.05]; %1th column is the shape; 2nd and 3rd are parameters used to compute density
    prior_rho2_xp = [1,0.85,0.1];
    prior_std1_xp = [2,0.25,10]; %prior_stddp1 = [2,0.25,5];
    prior_std2_xp = [2,0.10,5];
end

rho1_tauc     =   0.9;     %0.9;%consumption tax rate
rho2_tauc     =   0;
p_tauc        =   0;
std1_tauc     =   0.104;
std2_tauc     =   0.01;
%set priors on parameters
prior_rho1_tauc = [1,0.85,0.01]; %1th column is the shape; 2nd and 3rd are parameters used to compute density 
prior_rho2_tauc = [1,0.1,0.1]; 
prior_std1_tauc = [2,0.01,2]; 
prior_std2_tauc = [2,0.00005,2];


rho1_sigma      =   0.845; %CMR:0.845;%BGG:0.845;NoFIS=0.833;
rho2_sigma      =   0;
p_sigma         =   8; %
std1_sigma      =   0.10334;
std2_sigma      =   0.055736;
%set priors on parameters
prior_rho1_sigma = [1,0.5,0.05]; %1th column is the shape; 2nd and 3rd are parameters used to compute density 
prior_rho2_sigma = [1,0.1,0.1]; 
prior_std1_sigma = [2,0.001,5]; %prior_stddsig1 = [2,0.01,5]; 
prior_std2_sigma = [2,0.001/sqrt(8),5];


rho1_zetac    =   0.9057; %CMR:0.9057;%BGG:0.90948;%CEE:0.89505; NoFIS=0.8932;
rho2_zetac    =   0;
p_zetac       =   0;
std1_zetac    =   0.019442;
std2_zetac    =   0.001;
%set priors on parameters
prior_rho1_zetac = [1,0.5,0.2]; %WARNING!!!! This has been changed from: prior_rho1_zetac = [1,0.5,0.025];
prior_rho2_zetac = [1,0.1,0.1]; 
prior_std1_zetac = [2,0.001,5]; %prior_stddzetac1 = [2,0.01,5]; 
prior_std2_zetac = [2,0.00005,2];


rho1_zetai    =   0.43595; %CMR:0.43595;%BGG:0.4593;%CEE:0.48281; NoFIS=0.4494;
rho2_zetai    =   0;
p_zetai       =   0;
std1_zetai    =   0.018175;
std2_zetai    =   0.001;
%set priors on parameters
prior_rho1_zetai = [1,0.5,0.05]; %1th column is the shape; 2nd and 3rd are parameters used to compute density 
prior_rho2_zetai = [1,0.1,0.1]; 
prior_std1_zetai = [2,0.001,5]; %prior_stddzetai1 = [2,0.01,5];
prior_std2_zetai = [2,0.001/sqrt(8),5];


rho1_tauo    =   0.95163; %CMR=0.95163; BGG=0.9439; CEE=0.92791; NoFis=0.9568
rho2_tauo    =   0;
p_tauo       =   0;
std1_tauo    =   0.13237;
std2_tauo    =   0.001;
%set priors on parameters
prior_rho1_tauo = [1,0.5,0.2]; %1th column is the shape; 2nd and 3rd are parameters used to compute density 
prior_rho2_tauo = [1,0.1,0.1]; 
prior_std1_tauo = [2,0.01,5]; %prior_stddtauo1 = [2,0.1,5];
prior_std2_tauo = [2,0.00005,2];


rho1_term    =   0.86883;
rho2_term    =   0;
p_term       =   0;
std1_term    =   0.0059727;
std2_term    =   0.00;
%set priors on parameters
prior_rho1_term = [1,0.5,0.2]; %1th column is the shape; 2nd and 3rd are parameters used to compute density 
prior_rho2_term = [1,0.1,0.1]; 
prior_std1_term = [2,0.01,5]; %[2,0.001,5];   
prior_std2_term = [2,0.00005,2];


%set the measurement error stdd, Vmeas
Vmeas = 0.001*ones(1,length(tauvar)); %0.01
abc = [1:20];
Vmeas(abc(tauvar==1)) = 0.016312; %0.090*0.1*1.25; %stocks
Vmeas(abc(tauvar==2)) = 0; %0.0023*0.1/2; %on inflation
Vmeas(abc(tauvar==3)) = 0; %0.0416*0.1*1.25; %on hours
Vmeas(abc(tauvar==4)) = 0.00090437; %0.0095*0.1*1.25; %on credit
Vmeas(abc(tauvar==5)) = 0; %0.0056*0.1/2; %on GDP
Vmeas(abc(tauvar==6)) = 0; %0.0080*0.1*1.25; %on wages
Vmeas(abc(tauvar==7)) = 0; %0.0152*0.1/2; %on investment
Vmeas(abc(tauvar==8)) = 0.0015513; %0.0151*0.1*1.25; %on M1
Vmeas(abc(tauvar==9)) = 0.00070831; %0.0074*0.1*1.25; %on M3
m3_m1 = 0;
if m3_m1 == 1;
   Vmeas(abc(tauvar==9)) = 0.0074;%0.00049714607675; %0.00052; %on M3
end
Vmeas(abc(tauvar==10))= 0; %0.0038*0.1/2; % %on consumption
Vmeas(abc(tauvar==11))= 4.7791e-005; %0.0005*0.1*1.25; %on premium
Vmeas(abc(tauvar==12))= 0.00026291; %0.0034*0.1*1.25; %on 10-year spread
Vmeas(abc(tauvar==13))=  0.00025; %Ra
Vmeas(abc(tauvar==14))= 0.00025194; %0.0046*0.1/2; %on Re
Vmeas(abc(tauvar==15))= 0.00463; %on utilisation
Vmeas(abc(tauvar==16))= 0.00079; %gov.consumption
Vmeas(abc(tauvar==17))= 0; %0.0034*0.1/2; %0.00072; %inv.price
Vmeas(abc(tauvar==18))= 0; %0.119*0.1*1.25; %0.01311; %oil
Vmeas(abc(tauvar==19))= 0.000336*1; %2-year spread
Vmeas(abc(tauvar==20))= 0.00068157; %.000727/2; %bank's reserves


prior_1 = [6,0.090*0.1*1,5]; %[6,0.090*0.1*1.25,5];WARNING: prior_1 = [6,0.009195/2,5];
prior_2 = [6,0.0023*0.1/2,5];
prior_3 = [6,0.0416*0.1*1.25,5];%WARNING: prior_3 = [6,0.004174/2,5];
prior_4 = [6,0.0095*0.1*1,5];%[6,0.0095*0.1*1.25,5];WARNING: prior_4 = [6,0.000954/2,5];
prior_5 = [6,0.0056*0.1/2,5];
prior_6 = [6,0.0080*0.1*1.25,5];%WARNING: prior_6 = [6,0.000809/2,5];
prior_7 = [6,0.0152*0.1/2,5];
prior_8 = [6,0.0151*0.1*1,5];%[6,0.0151*0.1*1.25,5];WARNING: prior_8 = [6,0.001550/2,5];
prior_9 = [6,0.0074*0.1*1,5];%[6,0.0074*0.1*1.25,5];WARNING: prior_9 = [6,0.000750/2,5];
m3_m1 = 0;
if m3_m1 == 1;
   prior_9 = [6,0.0077*0.1,5]; %%on M3
end
prior_10 = [6,0.0038*0.1/2,5];
prior_11 = [6,0.0005*0.1*1,5];%[6,0.0005*0.1*1.25,5];WARNING: prior_11 = [6,0.00010,5];
prior_12 = [6,0.0034*0.1*1,5];%[6,0.0034*0.1*1.25,5];WARNING: prior_12 = [6,0.000336/2,5];
prior_13 = [6,0.00025,5];
prior_14 = [6,0.0046*0.1*1,5];%[6,0.0046*0.1/2,5];
prior_15 = [6,0.00463,5];
prior_16 = [6,0.00079,5];
prior_17 = [6,0.0034*0.1/2,5];
prior_18 = [6,0.119*0.1*1.25,5];%WARNING: prior_18 = [6,0.0120727/2,5];
prior_19 = [6,0.000336*1,5]; %
prior_20 = [6,0.0071*0.1*1,5];%[6,0.0071/2,5];

% %monetary responses to shocks
% if Taylor == 0
%     phif = -0.01;
%     phitau = .01;
%     phipsil = .01;
%     phipsik = .01;
%     phiksi = 0.01;
%     phixb = .01;
%     phiup = .01;
%     phitheta = 0;
%     phichii = 0;
%     phitaul = .01;
%     phitauk = .01;
%     phizeta = .01;
%     phig = -0.232;
%     phiv = 0;%-0.078;
%     phitauD = .01;
%     phimuz = 150;%300;%150;
%     phigamma = .01;
%     phieps = 0;%-0.982;
%     phitauC = .01;
%     phisig = 0;%0.096;
% elseif Taylor == 1 | Taylor ==2
%     phif = 0;
%     phitau = 0;
%     phipsil = 0;
%     phipsik = 0;
%     phiksi = 0;
%     phixb = 0;
%     phiup = 0;
%     phitheta = 0;
%     phichii = 0;
%     phitaul = 0;
%     phitauk = 0;
%     phizeta = 0;
%     phig = 0;
%     phiv = 0;
%     phitauD = 0;
%     phimuz = 0;
%     phigamma = 0;
%     phieps = 0;
%     phitauC = 0;
%     phisig = 0;
% end

