function [logden] = priordens(xx,prior);
% Computes prior density 
%shape:             %       1 is BETA(mean,stdd); parameters a and b needed to evaluate Beta distribution are computed automatically on the basis of the 'mean' and 'stdd' specified by the user
                    %       2 is INVGAMMA(mode,d); d gives the degrees of freedom
                    %       3 is NORMAL(mean,stdd)
                    %       4 is uniform(a,b)
                    %       5 is Gamma(mean,stdd)
                    %       6 is Weibull(a,b); a governs roughly the mode and b the dispersion (>2 and the higher the tigher)


logden = 0;
nn = length(xx);

for i=1:nn
    if prior(i,1) == 1;  %BETA Prior
        [a,b] = betapar(prior(i,2),prior(i,3));
        logf = logbetapdf(xx(i),a,b);
        logden = logden + logf;
    elseif prior(i,1) == 2; %INVGAMMA Prior
        logf = logigammapdf(xx(i),prior(i,2),prior(i,3));
        logden = logden + logf;
    elseif prior(i,1) == 3;  %GAUSSIAN prior
        logf = lognormpdf(xx(i),prior(i,2),prior(i,3));
        logden = logden + logf;
    elseif prior(i,1) == 4; %Uniform Prior
        a = prior(i,2);
        b = prior(i,3);
        if xx(i) >b | xx(i)<a
            logden = -1.e10;
            return
        else
            logden = logden + log(1/(b-a));
        end
    elseif prior(i,1) == 5 %Gamma prior
        logf = lgammapdf(xx(i),prior(i,2),prior(i,3));
        logden = logden + logf;
    elseif prior(i,1) == 6 %Weibull
        ff = wblpdf(xx(i),prior(i,2),prior(i,3));
        logf = log(ff);
        logden = logden + logf;
    end
end

